/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<imagecolors.h>)
#  include <imagecolors.h>
#endif
#if __has_include(<overlayzstackingattached.h>)
#  include <overlayzstackingattached.h>
#endif
#if __has_include(<spellcheckattached.h>)
#  include <spellcheckattached.h>
#endif
#if __has_include(<wheelhandler.h>)
#  include <wheelhandler.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigami()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ImageColors>("org.kde.kirigami", 2);
    qmlRegisterTypesAndRevisions<KirigamiWheelEvent>("org.kde.kirigami", 2);
    qmlRegisterTypesAndRevisions<OverlayZStackingAttached>("org.kde.kirigami", 2);
    qmlRegisterEnum<OverlayZStackingAttached::Layer>("OverlayZStackingAttached::Layer");
    qmlRegisterTypesAndRevisions<PaletteSwatch>("org.kde.kirigami", 2);
    qmlRegisterTypesAndRevisions<SpellCheckAttached>("org.kde.kirigami", 2);
    qmlRegisterTypesAndRevisions<WheelHandler>("org.kde.kirigami", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigami", 2, 0);
}

static const QQmlModuleRegistration orgkdekirigamiRegistration("org.kde.kirigami", qml_register_types_org_kde_kirigami);
