/****************************************************************************
** Meta object code from reading C++ file 'units.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.29.0/src/platform/units.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'units.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Kirigami8Platform9IconSizesE_t {};
} // unnamed namespace

template <> constexpr inline auto Kirigami::Platform::IconSizes::qt_create_metaobjectdata<qt_meta_tag_ZN8Kirigami8Platform9IconSizesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kirigami::Platform::IconSizes",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Grouped Property",
        "sizeForLabelsChanged",
        "",
        "smallChanged",
        "smallMediumChanged",
        "mediumChanged",
        "largeChanged",
        "hugeChanged",
        "enormousChanged",
        "roundedIconSize",
        "size",
        "sizeForLabels",
        "small",
        "smallMedium",
        "medium",
        "large",
        "huge",
        "enormous"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sizeForLabelsChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'smallChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'smallMediumChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediumChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'largeChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hugeChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enormousChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'roundedIconSize'
        QtMocHelpers::MethodData<int(int) const>(15, 8, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sizeForLabels'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'small'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'smallMedium'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'medium'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'large'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'huge'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'enormous'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<IconSizes, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Kirigami::Platform::IconSizes::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform9IconSizesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform9IconSizesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Kirigami8Platform9IconSizesE_t>.metaTypes,
    nullptr
} };

void Kirigami::Platform::IconSizes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IconSizes *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sizeForLabelsChanged(); break;
        case 1: _t->smallChanged(); break;
        case 2: _t->smallMediumChanged(); break;
        case 3: _t->mediumChanged(); break;
        case 4: _t->largeChanged(); break;
        case 5: _t->hugeChanged(); break;
        case 6: _t->enormousChanged(); break;
        case 7: { int _r = _t->roundedIconSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IconSizes::*)()>(_a, &IconSizes::sizeForLabelsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconSizes::*)()>(_a, &IconSizes::smallChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconSizes::*)()>(_a, &IconSizes::smallMediumChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconSizes::*)()>(_a, &IconSizes::mediumChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconSizes::*)()>(_a, &IconSizes::largeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconSizes::*)()>(_a, &IconSizes::hugeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconSizes::*)()>(_a, &IconSizes::enormousChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->sizeForLabels(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->small(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->smallMedium(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->medium(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->large(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->huge(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->enormous(); break;
        default: break;
        }
    }
}

const QMetaObject *Kirigami::Platform::IconSizes::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::Platform::IconSizes::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform9IconSizesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::Platform::IconSizes::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Kirigami::Platform::IconSizes::sizeForLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kirigami::Platform::IconSizes::smallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kirigami::Platform::IconSizes::smallMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kirigami::Platform::IconSizes::mediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Kirigami::Platform::IconSizes::largeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Kirigami::Platform::IconSizes::hugeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Kirigami::Platform::IconSizes::enormousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
namespace {
struct qt_meta_tag_ZN8Kirigami8Platform5UnitsE_t {};
} // unnamed namespace

template <> constexpr inline auto Kirigami::Platform::Units::qt_create_metaobjectdata<qt_meta_tag_ZN8Kirigami8Platform5UnitsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kirigami::Platform::Units",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "gridUnitChanged",
        "",
        "smallSpacingChanged",
        "mediumSpacingChanged",
        "largeSpacingChanged",
        "veryLongDurationChanged",
        "longDurationChanged",
        "shortDurationChanged",
        "veryShortDurationChanged",
        "humanMomentChanged",
        "toolTipDelayChanged",
        "wheelScrollLinesChanged",
        "cornerRadiusChanged",
        "gridUnit",
        "iconSizes",
        "Kirigami::Platform::IconSizes*",
        "smallSpacing",
        "mediumSpacing",
        "largeSpacing",
        "veryLongDuration",
        "longDuration",
        "shortDuration",
        "veryShortDuration",
        "humanMoment",
        "toolTipDelay",
        "cornerRadius"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gridUnitChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'smallSpacingChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediumSpacingChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'largeSpacingChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'veryLongDurationChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'longDurationChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shortDurationChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'veryShortDurationChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'humanMomentChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolTipDelayChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wheelScrollLinesChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cornerRadiusChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'gridUnit'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'iconSizes'
        QtMocHelpers::PropertyData<Kirigami::Platform::IconSizes*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'smallSpacing'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'mediumSpacing'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'largeSpacing'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'veryLongDuration'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'longDuration'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'shortDuration'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 6),
        // property 'veryShortDuration'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 7),
        // property 'humanMoment'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'toolTipDelay'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'cornerRadius'
        QtMocHelpers::PropertyData<qreal>(30, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Units, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Kirigami::Platform::Units::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform5UnitsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform5UnitsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Kirigami8Platform5UnitsE_t>.metaTypes,
    nullptr
} };

void Kirigami::Platform::Units::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Units *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gridUnitChanged(); break;
        case 1: _t->smallSpacingChanged(); break;
        case 2: _t->mediumSpacingChanged(); break;
        case 3: _t->largeSpacingChanged(); break;
        case 4: _t->veryLongDurationChanged(); break;
        case 5: _t->longDurationChanged(); break;
        case 6: _t->shortDurationChanged(); break;
        case 7: _t->veryShortDurationChanged(); break;
        case 8: _t->humanMomentChanged(); break;
        case 9: _t->toolTipDelayChanged(); break;
        case 10: _t->wheelScrollLinesChanged(); break;
        case 11: _t->cornerRadiusChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::gridUnitChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::smallSpacingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::mediumSpacingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::largeSpacingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::veryLongDurationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::longDurationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::shortDurationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::veryShortDurationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::humanMomentChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::toolTipDelayChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::wheelScrollLinesChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Units::*)()>(_a, &Units::cornerRadiusChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Kirigami::Platform::IconSizes* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->gridUnit(); break;
        case 1: *reinterpret_cast<Kirigami::Platform::IconSizes**>(_v) = _t->iconSizes(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->smallSpacing(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->mediumSpacing(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->largeSpacing(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->veryLongDuration(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->longDuration(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->shortDuration(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->veryShortDuration(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->humanMoment(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->toolTipDelay(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->cornerRadius(); break;
        default: break;
        }
    }
}

const QMetaObject *Kirigami::Platform::Units::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::Platform::Units::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform5UnitsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::Platform::Units::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Kirigami::Platform::Units::gridUnitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kirigami::Platform::Units::smallSpacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kirigami::Platform::Units::mediumSpacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kirigami::Platform::Units::largeSpacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Kirigami::Platform::Units::veryLongDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Kirigami::Platform::Units::longDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Kirigami::Platform::Units::shortDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Kirigami::Platform::Units::veryShortDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Kirigami::Platform::Units::humanMomentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Kirigami::Platform::Units::toolTipDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Kirigami::Platform::Units::wheelScrollLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Kirigami::Platform::Units::cornerRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
