/****************************************************************************
** Meta object code from reading C++ file 'enums.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.29.0/src/controls/enums.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'enums.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22ApplicationHeaderStyleE_t {};
} // unnamed namespace

template <> constexpr inline auto ApplicationHeaderStyle::qt_create_metaobjectdata<qt_meta_tag_ZN22ApplicationHeaderStyleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ApplicationHeaderStyle",
        "QML.Element",
        "auto",
        "Status",
        "Auto",
        "Breadcrumb",
        "Titles",
        "ToolBar",
        "None",
        "NavigationButton",
        "NoNavigationButtons",
        "ShowBackButton",
        "ShowForwardButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<Status>(3, 3, QMC::EnumFlags{}).add({
            {    4, Status::Auto },
            {    5, Status::Breadcrumb },
            {    6, Status::Titles },
            {    7, Status::ToolBar },
            {    8, Status::None },
        }),
        // enum 'NavigationButton'
        QtMocHelpers::EnumData<NavigationButton>(9, 9, QMC::EnumFlags{}).add({
            {   10, NavigationButton::NoNavigationButtons },
            {   11, NavigationButton::ShowBackButton },
            {   12, NavigationButton::ShowForwardButton },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN22ApplicationHeaderStyleE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN22ApplicationHeaderStyleE =
    ApplicationHeaderStyle::qt_create_metaobjectdata<qt_meta_tag_ZN22ApplicationHeaderStyleE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN22ApplicationHeaderStyleE =
    qt_staticMetaObjectContent_ZN22ApplicationHeaderStyleE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN22ApplicationHeaderStyleE =
    qt_staticMetaObjectContent_ZN22ApplicationHeaderStyleE.relocatingData;

Q_CONSTINIT const QMetaObject ApplicationHeaderStyle::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN22ApplicationHeaderStyleE.stringdata,
    qt_staticMetaObjectStaticContent_ZN22ApplicationHeaderStyleE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN22ApplicationHeaderStyleE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN11MessageTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto MessageType::qt_create_metaobjectdata<qt_meta_tag_ZN11MessageTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MessageType",
        "QML.Element",
        "auto",
        "Type",
        "Information",
        "Positive",
        "Warning",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<Type>(3, 3, QMC::EnumFlags{}).add({
            {    4, Type::Information },
            {    5, Type::Positive },
            {    6, Type::Warning },
            {    7, Type::Error },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN11MessageTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN11MessageTypeE =
    MessageType::qt_create_metaobjectdata<qt_meta_tag_ZN11MessageTypeE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN11MessageTypeE =
    qt_staticMetaObjectContent_ZN11MessageTypeE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN11MessageTypeE =
    qt_staticMetaObjectContent_ZN11MessageTypeE.relocatingData;

Q_CONSTINIT const QMetaObject MessageType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN11MessageTypeE.stringdata,
    qt_staticMetaObjectStaticContent_ZN11MessageTypeE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN11MessageTypeE.metaTypes,
    nullptr
} };

QT_WARNING_POP
