/****************************************************************************
** Meta object code from reading C++ file 'imagecolors.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kirigami-6.29.0/src/imagecolors.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imagecolors.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13PaletteSwatchE_t {};
} // unnamed namespace

template <> constexpr inline auto PaletteSwatch::qt_create_metaobjectdata<qt_meta_tag_ZN13PaletteSwatchE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PaletteSwatch",
        "QML.Element",
        "imageColorsPaletteSwatch",
        "ratio",
        "color",
        "QColor",
        "contrastColor"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ratio'
        QtMocHelpers::PropertyData<qreal>(3, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'contrastColor'
        QtMocHelpers::PropertyData<QColor>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PaletteSwatch, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PaletteSwatch::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PaletteSwatchE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PaletteSwatchE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13PaletteSwatchE_t>.metaTypes,
    nullptr
} };

void PaletteSwatch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<PaletteSwatch *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->ratio(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->contrastColor(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN11ImageColorsE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageColors::qt_create_metaobjectdata<qt_meta_tag_ZN11ImageColorsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageColors",
        "QML.Element",
        "auto",
        "sourceChanged",
        "",
        "paletteChanged",
        "fallbackPaletteChanged",
        "fallbackPaletteBrightnessChanged",
        "fallbackAverageChanged",
        "fallbackDominantChanged",
        "fallbackDominantContrastingChanged",
        "fallbackHighlightChanged",
        "fallbackForegroundChanged",
        "fallbackBackgroundChanged",
        "update",
        "source",
        "QVariant",
        "palette",
        "QList<PaletteSwatch>",
        "paletteBrightness",
        "ColorUtils::Brightness",
        "average",
        "QColor",
        "dominant",
        "dominantContrast",
        "highlight",
        "foreground",
        "background",
        "closestToWhite",
        "closestToBlack",
        "fallbackPalette",
        "fallbackPaletteBrightness",
        "fallbackAverage",
        "fallbackDominant",
        "fallbackDominantContrasting",
        "fallbackHighlight",
        "fallbackForeground",
        "fallbackBackground"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackPaletteChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackPaletteBrightnessChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackAverageChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackDominantChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackDominantContrastingChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackHighlightChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackForegroundChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackBackgroundChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'update'
        QtMocHelpers::MethodData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QVariant>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'palette'
        QtMocHelpers::PropertyData<QList<PaletteSwatch>>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'paletteBrightness'
        QtMocHelpers::PropertyData<ColorUtils::Brightness>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'average'
        QtMocHelpers::PropertyData<QColor>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'dominant'
        QtMocHelpers::PropertyData<QColor>(23, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'dominantContrast'
        QtMocHelpers::PropertyData<QColor>(24, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'highlight'
        QtMocHelpers::PropertyData<QColor>(25, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'foreground'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'background'
        QtMocHelpers::PropertyData<QColor>(27, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'closestToWhite'
        QtMocHelpers::PropertyData<QColor>(28, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'closestToBlack'
        QtMocHelpers::PropertyData<QColor>(29, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'fallbackPalette'
        QtMocHelpers::PropertyData<QList<PaletteSwatch>>(30, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'fallbackPaletteBrightness'
        QtMocHelpers::PropertyData<ColorUtils::Brightness>(31, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 3),
        // property 'fallbackAverage'
        QtMocHelpers::PropertyData<QColor>(32, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 4),
        // property 'fallbackDominant'
        QtMocHelpers::PropertyData<QColor>(33, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 5),
        // property 'fallbackDominantContrasting'
        QtMocHelpers::PropertyData<QColor>(34, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 6),
        // property 'fallbackHighlight'
        QtMocHelpers::PropertyData<QColor>(35, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 7),
        // property 'fallbackForeground'
        QtMocHelpers::PropertyData<QColor>(36, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 8),
        // property 'fallbackBackground'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ImageColors, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11ImageColorsE[] = {
    QMetaObject::SuperData::link<ColorUtils::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ImageColors::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ImageColorsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ImageColorsE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11ImageColorsE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ImageColorsE_t>.metaTypes,
    nullptr
} };

void ImageColors::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageColors *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->paletteChanged(); break;
        case 2: _t->fallbackPaletteChanged(); break;
        case 3: _t->fallbackPaletteBrightnessChanged(); break;
        case 4: _t->fallbackAverageChanged(); break;
        case 5: _t->fallbackDominantChanged(); break;
        case 6: _t->fallbackDominantContrastingChanged(); break;
        case 7: _t->fallbackHighlightChanged(); break;
        case 8: _t->fallbackForegroundChanged(); break;
        case 9: _t->fallbackBackgroundChanged(); break;
        case 10: _t->update(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::paletteChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackPaletteChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackPaletteBrightnessChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackAverageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackDominantChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackDominantContrastingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackHighlightChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackForegroundChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageColors::*)()>(_a, &ImageColors::fallbackBackgroundChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<QList<PaletteSwatch>*>(_v) = _t->palette(); break;
        case 2: *reinterpret_cast<ColorUtils::Brightness*>(_v) = _t->paletteBrightness(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->average(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->dominant(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->dominantContrast(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->highlight(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->foreground(); break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->background(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->closestToWhite(); break;
        case 10: *reinterpret_cast<QColor*>(_v) = _t->closestToBlack(); break;
        case 11: *reinterpret_cast<QList<PaletteSwatch>*>(_v) = _t->m_fallbackPalette; break;
        case 12: *reinterpret_cast<ColorUtils::Brightness*>(_v) = _t->m_fallbackPaletteBrightness; break;
        case 13: *reinterpret_cast<QColor*>(_v) = _t->m_fallbackAverage; break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->m_fallbackDominant; break;
        case 15: *reinterpret_cast<QColor*>(_v) = _t->m_fallbackDominantContrasting; break;
        case 16: *reinterpret_cast<QColor*>(_v) = _t->m_fallbackHighlight; break;
        case 17: *reinterpret_cast<QColor*>(_v) = _t->m_fallbackForeground; break;
        case 18: *reinterpret_cast<QColor*>(_v) = _t->m_fallbackBackground; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QVariant*>(_v)); break;
        case 11:
            if (QtMocHelpers::setProperty(_t->m_fallbackPalette, *reinterpret_cast<QList<PaletteSwatch>*>(_v)))
                Q_EMIT _t->fallbackPaletteChanged();
            break;
        case 12:
            if (QtMocHelpers::setProperty(_t->m_fallbackPaletteBrightness, *reinterpret_cast<ColorUtils::Brightness*>(_v)))
                Q_EMIT _t->fallbackPaletteBrightnessChanged();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->m_fallbackAverage, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->fallbackAverageChanged();
            break;
        case 14:
            if (QtMocHelpers::setProperty(_t->m_fallbackDominant, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->fallbackDominantChanged();
            break;
        case 15:
            if (QtMocHelpers::setProperty(_t->m_fallbackDominantContrasting, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->fallbackDominantContrastingChanged();
            break;
        case 16:
            if (QtMocHelpers::setProperty(_t->m_fallbackHighlight, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->fallbackHighlightChanged();
            break;
        case 17:
            if (QtMocHelpers::setProperty(_t->m_fallbackForeground, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->fallbackForegroundChanged();
            break;
        case 18:
            if (QtMocHelpers::setProperty(_t->m_fallbackBackground, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->fallbackBackgroundChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *ImageColors::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageColors::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ImageColorsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageColors::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void ImageColors::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImageColors::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImageColors::fallbackPaletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ImageColors::fallbackPaletteBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImageColors::fallbackAverageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ImageColors::fallbackDominantChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ImageColors::fallbackDominantContrastingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ImageColors::fallbackHighlightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ImageColors::fallbackForegroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ImageColors::fallbackBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
