// /qt/qml/org/kde/kirigami/controls/private/DefaultChipBackground.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_kirigami_controls_private_DefaultChipBackground_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x34,0x11,0x0,0x0,0x9d,0x3b,0x12,0x30,
0x11,0x9d,0x5e,0xc0,0x84,0x7b,0x5,0xd8,
0x55,0x5e,0xb5,0x33,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x2f,0x0,0x0,0x0,0xa0,0x7,0x0,0x0,
0xa,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x5f,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x2,0x0,0x0,
0x5,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x2,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc0,0xe,0x0,0x0,
0x98,0x2,0x0,0x0,0xf0,0x2,0x0,0x0,
0x68,0x3,0x0,0x0,0xe0,0x3,0x0,0x0,
0x50,0x4,0x0,0x0,0xc8,0x4,0x0,0x0,
0x40,0x5,0x0,0x0,0x98,0x5,0x0,0x0,
0x60,0x6,0x0,0x0,0xb8,0x6,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xc0,0x1,0x0,0x0,0xd3,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x0,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x10,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0xe4,0x1,0x0,0x0,0xd3,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x0,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x10,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0xe4,0x1,0x0,0x0,0x23,0x0,0x0,0x0,
0x30,0x2,0x0,0x0,0x23,0x0,0x0,0x0,
0xb0,0x1,0x0,0x0,0xc0,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x50,0x2,0x0,0x0,0x23,0x0,0x0,0x0,
0xb0,0x1,0x0,0x0,0x60,0x2,0x0,0x0,
0x44,0x2,0x0,0x0,0xd3,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x0,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x10,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0xe4,0x1,0x0,0x0,0xd3,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x0,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x10,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0xe4,0x1,0x0,0x0,0x23,0x0,0x0,0x0,
0xb0,0x1,0x0,0x0,0x70,0x2,0x0,0x0,
0x83,0x2,0x0,0x0,0x43,0x0,0x0,0x0,
0x90,0x2,0x0,0x0,0xa0,0x2,0x0,0x0,
0xa3,0x0,0x0,0x0,0xb0,0x2,0x0,0x0,
0xc3,0x0,0x0,0x0,0x83,0x0,0x0,0x0,
0x23,0x0,0x0,0x0,0xc0,0x2,0x0,0x0,
0xd0,0x2,0x0,0x0,0x83,0x2,0x0,0x0,
0x43,0x0,0x0,0x0,0x90,0x2,0x0,0x0,
0xa0,0x2,0x0,0x0,0x23,0x1,0x0,0x0,
0xb0,0x2,0x0,0x0,0x3,0x1,0x0,0x0,
0xe0,0x2,0x0,0x0,0x43,0x1,0x0,0x0,
0xe3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0x5,0x40,
0x33,0x33,0x33,0x33,0x33,0x73,0x26,0x40,
0x9a,0x99,0x99,0x99,0x99,0xd9,0x3c,0x40,
0xcd,0xcc,0xcc,0xcc,0xcc,0x8c,0x19,0x40,
0x66,0x66,0x66,0x66,0x66,0x26,0x13,0x40,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x3c,0x2,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xe,0x0,0x0,0x0,
0x13,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x3,0x18,0x7,
0x2e,0x4,0x3c,0x5,0x3c,0x6,0x3c,0x7,
0x18,0xa,0x2e,0x8,0x3c,0x9,0x3c,0xa,
0x3c,0xb,0x18,0xb,0x2e,0xc,0x3c,0xd,
0x3c,0xe,0x3c,0xf,0x18,0xc,0x14,0x1,
0xd,0xac,0x10,0x7,0x4,0xa,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xe,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x11,0x18,0x7,
0x2e,0x12,0x3c,0x13,0x3c,0x14,0x3c,0x15,
0x18,0xa,0x2e,0x16,0x3c,0x17,0x3c,0x18,
0x3c,0x19,0x18,0xb,0x2e,0x1a,0x3c,0x1b,
0x3c,0x1c,0x3c,0x1d,0x18,0xc,0x14,0x2,
0xd,0xac,0x1e,0x7,0x4,0xa,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x26,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x1e,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1f,0x3c,0x20,
0x18,0x7,0x2e,0x21,0x3c,0x22,0x3c,0x23,
0x18,0xa,0x2e,0x24,0x3c,0x25,0x3c,0x26,
0x18,0xb,0x2e,0x27,0x3c,0x28,0x3c,0x29,
0x18,0xc,0xac,0x2a,0x7,0x3,0xa,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xe,0x0,0x0,0x0,
0x24,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2b,0x18,0x7,
0x2e,0x2c,0x3c,0x2d,0x3c,0x2e,0x3c,0x2f,
0x18,0xa,0x2e,0x30,0x3c,0x31,0x3c,0x32,
0x3c,0x33,0x18,0xb,0x2e,0x34,0x3c,0x35,
0x3c,0x36,0x3c,0x37,0x18,0xc,0x14,0x3,
0xd,0xac,0x38,0x7,0x4,0xa,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xe,0x0,0x0,0x0,
0x2a,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x39,0x18,0x7,
0x2e,0x3a,0x3c,0x3b,0x3c,0x3c,0x3c,0x3d,
0x18,0xa,0x2e,0x3e,0x3c,0x3f,0x3c,0x40,
0x3c,0x41,0x18,0xb,0x2e,0x42,0x3c,0x43,
0x3c,0x44,0x3c,0x45,0x18,0xc,0x14,0x4,
0xd,0xac,0x46,0x7,0x4,0xa,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x30,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x47,0x3c,0x48,
0x3c,0x49,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x98,0x0,0x0,0x0,0x26,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x32,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x32,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x33,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x35,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x36,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x37,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x39,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x3b,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x1,0x2,0x7,0x1,0x2e,0x4a,0x18,0x8,
0x2e,0x4b,0x3c,0x4c,0xa4,0x8,0x18,0x7,
0x3c,0x4d,0x50,0x3,0x2e,0x4e,0x2,0x16,
0x7,0x3c,0x4f,0x50,0x3,0x2e,0x50,0x2,
0x2e,0x51,0x2,0x16,0x6,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x49,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x49,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x52,0x3c,0x53,
0x3c,0x54,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x2f,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0xa,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x3c,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x3d,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x3e,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x3f,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x41,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x42,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x26,0x0,0x0,0x0,
0x43,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x29,0x0,0x0,0x0,0x45,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x2c,0x0,0x0,0x0,
0x47,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x1,0x2,0x7,0x1,0x2e,0x55,0x18,0x8,
0x2e,0x56,0x3c,0x57,0xa4,0x8,0x18,0x7,
0x3c,0x58,0x50,0x3,0x2e,0x59,0x2,0x16,
0x7,0x3c,0x5a,0x50,0x3,0x2e,0x5b,0x2,
0x16,0x7,0x3c,0x5c,0x50,0x3,0x2e,0x5d,
0x2,0x2e,0x5e,0x2,0x16,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x60,0x8,0x0,0x0,0x68,0x8,0x0,0x0,
0x80,0x8,0x0,0x0,0x98,0x8,0x0,0x0,
0xd0,0x8,0x0,0x0,0xe0,0x8,0x0,0x0,
0x20,0x9,0x0,0x0,0x38,0x9,0x0,0x0,
0x48,0x9,0x0,0x0,0x68,0x9,0x0,0x0,
0xa8,0x9,0x0,0x0,0xc8,0x9,0x0,0x0,
0x8,0xa,0x0,0x0,0x28,0xa,0x0,0x0,
0x68,0xa,0x0,0x0,0x98,0xa,0x0,0x0,
0xe0,0xa,0x0,0x0,0x10,0xb,0x0,0x0,
0x58,0xb,0x0,0x0,0x88,0xb,0x0,0x0,
0xd0,0xb,0x0,0x0,0x0,0xc,0x0,0x0,
0x48,0xc,0x0,0x0,0x78,0xc,0x0,0x0,
0x90,0xc,0x0,0x0,0xa0,0xc,0x0,0x0,
0xb8,0xc,0x0,0x0,0xe8,0xc,0x0,0x0,
0xf8,0xc,0x0,0x0,0x20,0xd,0x0,0x0,
0x30,0xd,0x0,0x0,0x40,0xd,0x0,0x0,
0x68,0xd,0x0,0x0,0x70,0xd,0x0,0x0,
0x78,0xd,0x0,0x0,0x80,0xd,0x0,0x0,
0xa0,0xd,0x0,0x0,0xd0,0xd,0x0,0x0,
0xe8,0xd,0x0,0x0,0x8,0xe,0x0,0x0,
0x28,0xe,0x0,0x0,0x40,0xe,0x0,0x0,
0x50,0xe,0x0,0x0,0x60,0xe,0x0,0x0,
0x78,0xe,0x0,0x0,0x88,0xe,0x0,0x0,
0xa8,0xe,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x74,0x0,0x66,0x0,0x6f,0x0,
0x72,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x2e,0x0,0x70,0x0,
0x6c,0x0,0x61,0x0,0x74,0x0,0x66,0x0,
0x6f,0x0,0x72,0x0,0x6d,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x4b,0x0,0x54,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x2e,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x74,0x0,0x65,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x52,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x66,0x0,0x61,0x0,0x75,0x0,0x6c,0x0,
0x74,0x0,0x43,0x0,0x6f,0x0,0x6c,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x64,0x0,0x65,0x0,0x66,0x0,
0x61,0x0,0x75,0x0,0x6c,0x0,0x74,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x73,0x0,0x65,0x0,
0x64,0x0,0x43,0x0,0x6f,0x0,0x6c,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x70,0x0,0x72,0x0,0x65,0x0,
0x73,0x0,0x73,0x0,0x65,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x63,0x0,0x68,0x0,
0x65,0x0,0x63,0x0,0x6b,0x0,0x65,0x0,
0x64,0x0,0x43,0x0,0x6f,0x0,0x6c,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x63,0x0,0x68,0x0,0x65,0x0,
0x63,0x0,0x6b,0x0,0x65,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x66,0x0,0x61,0x0,0x75,0x0,0x6c,0x0,
0x74,0x0,0x42,0x0,0x6f,0x0,0x72,0x0,
0x64,0x0,0x65,0x0,0x72,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x64,0x0,0x65,0x0,0x66,0x0,
0x61,0x0,0x75,0x0,0x6c,0x0,0x74,0x0,
0x42,0x0,0x6f,0x0,0x72,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x63,0x0,0x68,0x0,
0x65,0x0,0x63,0x0,0x6b,0x0,0x65,0x0,
0x64,0x0,0x42,0x0,0x6f,0x0,0x72,0x0,
0x64,0x0,0x65,0x0,0x72,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x63,0x0,0x68,0x0,0x65,0x0,
0x63,0x0,0x6b,0x0,0x65,0x0,0x64,0x0,
0x42,0x0,0x6f,0x0,0x72,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x73,0x0,0x65,0x0,
0x64,0x0,0x42,0x0,0x6f,0x0,0x72,0x0,
0x64,0x0,0x65,0x0,0x72,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x70,0x0,0x72,0x0,0x65,0x0,
0x73,0x0,0x73,0x0,0x65,0x0,0x64,0x0,
0x42,0x0,0x6f,0x0,0x72,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x76,0x0,0x65,0x0,0x72,0x0,0x65,0x0,
0x64,0x0,0x42,0x0,0x6f,0x0,0x72,0x0,
0x64,0x0,0x65,0x0,0x72,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x68,0x0,0x6f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x65,0x0,0x64,0x0,
0x42,0x0,0x6f,0x0,0x72,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x63,0x0,0x6f,0x0,0x6c,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x72,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x72,0x0,0x61,0x0,
0x64,0x0,0x69,0x0,0x75,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x72,0x0,0x61,0x0,0x64,0x0,
0x69,0x0,0x75,0x0,0x73,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x54,0x0,0x68,0x0,
0x65,0x0,0x6d,0x0,0x65,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x67,0x0,
0x62,0x0,0x61,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x68,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x6c,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x72,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x67,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x62,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x55,0x0,
0x74,0x0,0x69,0x0,0x6c,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x6c,0x0,0x69,0x0,
0x6e,0x0,0x65,0x0,0x61,0x0,0x72,0x0,
0x49,0x0,0x6e,0x0,0x74,0x0,0x65,0x0,
0x72,0x0,0x70,0x0,0x6f,0x0,0x6c,0x0,
0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x74,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x43,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x66,0x0,0x72,0x0,
0x61,0x0,0x6d,0x0,0x65,0x0,0x43,0x0,
0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,
0x61,0x0,0x73,0x0,0x74,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x76,0x0,0x65,0x0,0x72,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x43,0x0,0x68,0x0,
0x69,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x64,0x0,0x6f,0x0,
0x77,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x63,0x0,0x68,0x0,
0x65,0x0,0x63,0x0,0x6b,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x55,0x0,0x6e,0x0,
0x69,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x72,0x0,0x6e,0x0,0x65,0x0,0x72,0x0,
0x52,0x0,0x61,0x0,0x64,0x0,0x69,0x0,
0x75,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x76,0x0,0x65,0x0,0x72,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x5,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x54,0x0,0x0,0x0,
0xec,0x1,0x0,0x0,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x7,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0xa8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa8,0x0,0x0,0x0,0xa8,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0xa8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0x8,0x0,0x10,0x0,0x0,0x0,0x0,0x0,
0x98,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x98,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0xa,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x13,0x0,0x50,0x0,
0xc,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0xe,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x1e,0x0,0x50,0x0,
0x10,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x24,0x0,0x50,0x0,0x12,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x2a,0x0,0x50,0x0,
0x14,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x30,0x0,0x50,0x0,0x19,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x49,0x0,0x50,0x0,
0x49,0x0,0xd0,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x32,0x0,0x50,0x0,
0x32,0x0,0xc0,0x0,0x14,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x0,0x40,0x1,
0x30,0x0,0x80,0x2,0x12,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2a,0x0,0x40,0x1,
0x2a,0x0,0x80,0x2,0x10,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x0,0x40,0x1,
0x24,0x0,0x80,0x2,0xe,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x40,0x1,
0x1e,0x0,0x80,0x2,0xc,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x40,0x1,
0x19,0x0,0x20,0x2,0xa,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x40,0x1,
0x13,0x0,0x20,0x2,0x8,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x40,0x1,
0xd,0x0,0x20,0x2,0x17,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3c,0x0,0x50,0x0,
0x3c,0x0,0xc0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x3c,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x48,0x0,0xc0,0x0,0x48,0x0,0x30,0x1,
0x7,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3c,0x0,0xc0,0x0,0x3c,0x0,0x30,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for defaultColor at line 13, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
QVariant v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadAttachedLookup(1, aotContext->qmlScopeObject, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadAttachedLookup(1, 2, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
s.v2_4 = QVariant(aotContext->lookupResultMetaType(2));
while (!aotContext->getObjectLookup(2, s.v2_2, s.v2_4.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(2, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_4 = QVariant(aotContext->lookupResultMetaType(2));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_4.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_4.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_4.data());
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for hoveredBorderColor at line 48, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
QVariant v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadAttachedLookup(72, aotContext->qmlScopeObject, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadAttachedLookup(72, 2, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
s.v2_4 = QVariant(aotContext->lookupResultMetaType(73));
while (!aotContext->getObjectLookup(73, s.v2_2, s.v2_4.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(73, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_4 = QVariant(aotContext->lookupResultMetaType(73));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_4.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_4.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_4.data());
}
return;
}
 },{ 7, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for color at line 50, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_12, markStack);
    aotContext->mark(v2_20, markStack);
    aotContext->mark(v2_29, markStack);
    aotContext->mark(v2_32, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QObject *v2_4 = nullptr;
QVariant v2_20;
QVariant v2_29;
QVariant v2_32;
bool v2_16;
bool v2_25;
const QMetaObject *v2_10 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(74, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(74);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->loadTypeLookup(76, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initLoadTypeLookup(76, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_As
s.v2_12 = s.v2_10->cast(s.v2_4);
{
}
// generate_StoreReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getObjectLookup(77, s.v2_12, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetObjectLookup(77, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_16) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
s.v2_20 = QVariant(aotContext->lookupResultMetaType(78));
while (!aotContext->loadScopeObjectPropertyLookup(78, s.v2_20.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
aotContext->initLoadScopeObjectPropertyLookup(78);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_20 = QVariant(aotContext->lookupResultMetaType(78));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_20.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_20.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_20.data());
}
return;
label_0:;
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
while (!aotContext->getObjectLookup(79, s.v2_12, &s.v2_25)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
aotContext->initGetObjectLookup(79, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_25) {
    goto label_1;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(31);
#endif
s.v2_29 = QVariant(aotContext->lookupResultMetaType(80));
while (!aotContext->loadScopeObjectPropertyLookup(80, s.v2_29.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(31);
#endif
aotContext->initLoadScopeObjectPropertyLookup(80);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_29 = QVariant(aotContext->lookupResultMetaType(80));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_29.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_29.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_29.data());
}
return;
label_1:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
s.v2_32 = QVariant(aotContext->lookupResultMetaType(81));
while (!aotContext->loadScopeObjectPropertyLookup(81, s.v2_32.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
aotContext->initLoadScopeObjectPropertyLookup(81);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_32 = QVariant(aotContext->lookupResultMetaType(81));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_32.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_32.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_32.data());
}
return;
}
 },{ 8, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for radius at line 73, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(83, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(83, 2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(84, s.v2_2, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(84, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_4;
}
return;
}
 },{ 9, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for color at line 60, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_12, markStack);
    aotContext->mark(v2_20, markStack);
    aotContext->mark(v2_29, markStack);
    aotContext->mark(v2_38, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_41, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QObject *v2_4 = nullptr;
QVariant v2_20;
QVariant v2_29;
QVariant v2_38;
QVariant v2_41;
bool v2_16;
bool v2_25;
bool v2_34;
const QMetaObject *v2_10 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(85, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(85);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->loadTypeLookup(87, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initLoadTypeLookup(87, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_As
s.v2_12 = s.v2_10->cast(s.v2_4);
{
}
// generate_StoreReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getObjectLookup(88, s.v2_12, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetObjectLookup(88, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_16) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
s.v2_20 = QVariant(aotContext->lookupResultMetaType(89));
while (!aotContext->loadScopeObjectPropertyLookup(89, s.v2_20.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
aotContext->initLoadScopeObjectPropertyLookup(89);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_20 = QVariant(aotContext->lookupResultMetaType(89));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_20.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_20.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_20.data());
}
return;
label_0:;
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
while (!aotContext->getObjectLookup(90, s.v2_12, &s.v2_25)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
aotContext->initGetObjectLookup(90, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_25) {
    goto label_1;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(31);
#endif
s.v2_29 = QVariant(aotContext->lookupResultMetaType(91));
while (!aotContext->loadScopeObjectPropertyLookup(91, s.v2_29.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(31);
#endif
aotContext->initLoadScopeObjectPropertyLookup(91);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_29 = QVariant(aotContext->lookupResultMetaType(91));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_29.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_29.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_29.data());
}
return;
label_1:;
// generate_LoadReg
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
while (!aotContext->getObjectLookup(92, s.v2_12, &s.v2_34)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
aotContext->initGetObjectLookup(92, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_34) {
    goto label_2;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
s.v2_38 = QVariant(aotContext->lookupResultMetaType(93));
while (!aotContext->loadScopeObjectPropertyLookup(93, s.v2_38.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
aotContext->initLoadScopeObjectPropertyLookup(93);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_38 = QVariant(aotContext->lookupResultMetaType(93));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_38.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_38.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_38.data());
}
return;
label_2:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
s.v2_41 = QVariant(aotContext->lookupResultMetaType(94));
while (!aotContext->loadScopeObjectPropertyLookup(94, s.v2_41.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
aotContext->initLoadScopeObjectPropertyLookup(94);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QColor"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
s.v2_41 = QVariant(aotContext->lookupResultMetaType(94));
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_41.isValid())
        aotContext->setReturnValueUndefined();
    const QMetaType returnType = s.v2_41.metaType();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], s.v2_41.data());
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
