/****************************************************************************
** Meta object code from reading C++ file 'stylehints.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.29.0/src/platform/stylehints.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stylehints.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Kirigami8Platform10StyleHintsE_t {};
} // unnamed namespace

template <> constexpr inline auto Kirigami::Platform::StyleHints::qt_create_metaobjectdata<qt_meta_tag_ZN8Kirigami8Platform10StyleHintsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kirigami::Platform::StyleHints",
        "QML.Element",
        "auto",
        "QML.Attached",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Attached Property",
        "useAlternateBackgroundColorChanged",
        "",
        "showFramedBackgroundChanged",
        "tickMarkStepSizeChanged",
        "iconNameChanged",
        "iconSourceChanged",
        "useAlternateBackgroundColor",
        "showFramedBackground",
        "tickMarkStepSize",
        "iconName",
        "iconSource",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'useAlternateBackgroundColorChanged'
        QtMocHelpers::SignalData<void()>(8, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showFramedBackgroundChanged'
        QtMocHelpers::SignalData<void()>(10, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tickMarkStepSizeChanged'
        QtMocHelpers::SignalData<void()>(11, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconNameChanged'
        QtMocHelpers::SignalData<void()>(12, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconSourceChanged'
        QtMocHelpers::SignalData<void()>(13, 9, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'useAlternateBackgroundColor'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'showFramedBackground'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'tickMarkStepSize'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'iconSource'
        QtMocHelpers::PropertyData<QUrl>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
            {    4,    5 },
            {    6,    7 },
    });
    return QtMocHelpers::metaObjectData<StyleHints, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Kirigami::Platform::StyleHints::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform10StyleHintsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform10StyleHintsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Kirigami8Platform10StyleHintsE_t>.metaTypes,
    nullptr
} };

void Kirigami::Platform::StyleHints::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StyleHints *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->useAlternateBackgroundColorChanged(); break;
        case 1: _t->showFramedBackgroundChanged(); break;
        case 2: _t->tickMarkStepSizeChanged(); break;
        case 3: _t->iconNameChanged(); break;
        case 4: _t->iconSourceChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StyleHints::*)()>(_a, &StyleHints::useAlternateBackgroundColorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleHints::*)()>(_a, &StyleHints::showFramedBackgroundChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleHints::*)()>(_a, &StyleHints::tickMarkStepSizeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleHints::*)()>(_a, &StyleHints::iconNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleHints::*)()>(_a, &StyleHints::iconSourceChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->useAlternateBackgroundColor(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showFramedBackground(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->tickMarkStepSize(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->iconSource(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUseAlternateBackgroundColor(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setShowFramedBackground(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setTickMarkStepSize(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setIconName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setIconSource(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Kirigami::Platform::StyleHints::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::Platform::StyleHints::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform10StyleHintsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::Platform::StyleHints::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Kirigami::Platform::StyleHints::useAlternateBackgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kirigami::Platform::StyleHints::showFramedBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kirigami::Platform::StyleHints::tickMarkStepSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kirigami::Platform::StyleHints::iconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Kirigami::Platform::StyleHints::iconSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
