/****************************************************************************
** Meta object code from reading C++ file 'platformtheme.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.29.0/src/platform/platformtheme.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'platformtheme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Kirigami8Platform13PlatformThemeE_t {};
} // unnamed namespace

template <> constexpr inline auto Kirigami::Platform::PlatformTheme::qt_create_metaobjectdata<qt_meta_tag_ZN8Kirigami8Platform13PlatformThemeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kirigami::Platform::PlatformTheme",
        "QML.Element",
        "Theme",
        "QML.Attached",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Attached Property",
        "colorsChanged",
        "",
        "defaultFontChanged",
        "QFont",
        "font",
        "smallFontChanged",
        "fixedWidthFontChanged",
        "colorSetChanged",
        "Kirigami::Platform::PlatformTheme::ColorSet",
        "colorSet",
        "colorGroupChanged",
        "Kirigami::Platform::PlatformTheme::ColorGroup",
        "colorGroup",
        "paletteChanged",
        "QPalette",
        "pal",
        "inheritChanged",
        "inherit",
        "useAlternateBackgroundColorChanged",
        "alternate",
        "frameContrastChanged",
        "contrast",
        "iconFromTheme",
        "QIcon",
        "name",
        "QColor",
        "customColor",
        "ColorSet",
        "ColorGroup",
        "textColor",
        "disabledTextColor",
        "highlightedTextColor",
        "activeTextColor",
        "linkColor",
        "visitedLinkColor",
        "negativeTextColor",
        "neutralTextColor",
        "positiveTextColor",
        "backgroundColor",
        "alternateBackgroundColor",
        "highlightColor",
        "activeBackgroundColor",
        "linkBackgroundColor",
        "visitedLinkBackgroundColor",
        "negativeBackgroundColor",
        "neutralBackgroundColor",
        "positiveBackgroundColor",
        "focusColor",
        "hoverColor",
        "useAlternateBackgroundColor",
        "defaultFont",
        "smallFont",
        "fixedWidthFont",
        "palette",
        "frameContrast",
        "lightFrameContrast",
        "View",
        "Window",
        "Button",
        "Selection",
        "Tooltip",
        "Complementary",
        "Header",
        "ColorSetCount",
        "Disabled",
        "Active",
        "Inactive",
        "Normal",
        "ColorGroupCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorsChanged'
        QtMocHelpers::SignalData<void()>(8, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultFontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(10, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'smallFontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(13, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'fixedWidthFontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(14, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'colorSetChanged'
        QtMocHelpers::SignalData<void(Kirigami::Platform::PlatformTheme::ColorSet)>(15, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'colorGroupChanged'
        QtMocHelpers::SignalData<void(Kirigami::Platform::PlatformTheme::ColorGroup)>(18, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void(const QPalette &)>(21, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'inheritChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 9, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Signal 'useAlternateBackgroundColorChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 9, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'frameContrastChanged'
        QtMocHelpers::SignalData<void(qreal)>(28, 9, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 29 },
        }}),
        // Method 'iconFromTheme'
        QtMocHelpers::MethodData<QIcon(const QString &, const QColor &)>(30, 9, QMC::AccessPublic, 0x80000000 | 31, {{
            { QMetaType::QString, 32 }, { 0x80000000 | 33, 34 },
        }}),
        // Method 'iconFromTheme'
        QtMocHelpers::MethodData<QIcon(const QString &)>(30, 9, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 31, {{
            { QMetaType::QString, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorSet'
        QtMocHelpers::PropertyData<enum ColorSet>(17, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'colorGroup'
        QtMocHelpers::PropertyData<enum ColorGroup>(20, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
        // property 'inherit'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'disabledTextColor'
        QtMocHelpers::PropertyData<QColor>(38, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'highlightedTextColor'
        QtMocHelpers::PropertyData<QColor>(39, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag, 0),
        // property 'activeTextColor'
        QtMocHelpers::PropertyData<QColor>(40, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'linkColor'
        QtMocHelpers::PropertyData<QColor>(41, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'visitedLinkColor'
        QtMocHelpers::PropertyData<QColor>(42, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'negativeTextColor'
        QtMocHelpers::PropertyData<QColor>(43, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'neutralTextColor'
        QtMocHelpers::PropertyData<QColor>(44, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'positiveTextColor'
        QtMocHelpers::PropertyData<QColor>(45, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(46, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'alternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(47, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag, 0),
        // property 'highlightColor'
        QtMocHelpers::PropertyData<QColor>(48, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'activeBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(49, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag, 0),
        // property 'linkBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(50, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'visitedLinkBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(51, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag, 0),
        // property 'negativeBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(52, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag, 0),
        // property 'neutralBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(53, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag, 0),
        // property 'positiveBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(54, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag, 0),
        // property 'focusColor'
        QtMocHelpers::PropertyData<QColor>(55, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'hoverColor'
        QtMocHelpers::PropertyData<QColor>(56, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'useAlternateBackgroundColor'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8),
        // property 'defaultFont'
        QtMocHelpers::PropertyData<QFont>(58, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'smallFont'
        QtMocHelpers::PropertyData<QFont>(59, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'fixedWidthFont'
        QtMocHelpers::PropertyData<QFont>(60, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 3),
        // property 'palette'
        QtMocHelpers::PropertyData<QPalette>(61, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 6),
        // property 'frameContrast'
        QtMocHelpers::PropertyData<qreal>(62, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'lightFrameContrast'
        QtMocHelpers::PropertyData<qreal>(63, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColorSet'
        QtMocHelpers::EnumData<enum ColorSet>(35, 35, QMC::EnumFlags{}).add({
            {   64, ColorSet::View },
            {   65, ColorSet::Window },
            {   66, ColorSet::Button },
            {   67, ColorSet::Selection },
            {   68, ColorSet::Tooltip },
            {   69, ColorSet::Complementary },
            {   70, ColorSet::Header },
            {   71, ColorSet::ColorSetCount },
        }),
        // enum 'ColorGroup'
        QtMocHelpers::EnumData<enum ColorGroup>(36, 36, QMC::EnumFlags{}).add({
            {   72, ColorGroup::Disabled },
            {   73, ColorGroup::Active },
            {   74, ColorGroup::Inactive },
            {   75, ColorGroup::Normal },
            {   76, ColorGroup::ColorGroupCount },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
            {    4,    5 },
            {    6,    7 },
    });
    return QtMocHelpers::metaObjectData<PlatformTheme, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Kirigami::Platform::PlatformTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform13PlatformThemeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform13PlatformThemeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Kirigami8Platform13PlatformThemeE_t>.metaTypes,
    nullptr
} };

void Kirigami::Platform::PlatformTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlatformTheme *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorsChanged(); break;
        case 1: _t->defaultFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 2: _t->smallFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 3: _t->fixedWidthFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 4: _t->colorSetChanged((*reinterpret_cast<std::add_pointer_t<Kirigami::Platform::PlatformTheme::ColorSet>>(_a[1]))); break;
        case 5: _t->colorGroupChanged((*reinterpret_cast<std::add_pointer_t<Kirigami::Platform::PlatformTheme::ColorGroup>>(_a[1]))); break;
        case 6: _t->paletteChanged((*reinterpret_cast<std::add_pointer_t<QPalette>>(_a[1]))); break;
        case 7: _t->inheritChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->useAlternateBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->frameContrastChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 10: { QIcon _r = _t->iconFromTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QIcon*>(_a[0]) = std::move(_r); }  break;
        case 11: { QIcon _r = _t->iconFromTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QIcon*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)()>(_a, &PlatformTheme::colorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(const QFont & )>(_a, &PlatformTheme::defaultFontChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(const QFont & )>(_a, &PlatformTheme::smallFontChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(const QFont & )>(_a, &PlatformTheme::fixedWidthFontChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(Kirigami::Platform::PlatformTheme::ColorSet )>(_a, &PlatformTheme::colorSetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(Kirigami::Platform::PlatformTheme::ColorGroup )>(_a, &PlatformTheme::colorGroupChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(const QPalette & )>(_a, &PlatformTheme::paletteChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(bool )>(_a, &PlatformTheme::inheritChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(bool )>(_a, &PlatformTheme::useAlternateBackgroundColorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlatformTheme::*)(qreal )>(_a, &PlatformTheme::frameContrastChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ColorSet*>(_v) = _t->colorSet(); break;
        case 1: *reinterpret_cast<enum ColorGroup*>(_v) = _t->colorGroup(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->inherit(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->disabledTextColor(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->highlightedTextColor(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->activeTextColor(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->linkColor(); break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->visitedLinkColor(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->negativeTextColor(); break;
        case 10: *reinterpret_cast<QColor*>(_v) = _t->neutralTextColor(); break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->positiveTextColor(); break;
        case 12: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 13: *reinterpret_cast<QColor*>(_v) = _t->alternateBackgroundColor(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->highlightColor(); break;
        case 15: *reinterpret_cast<QColor*>(_v) = _t->activeBackgroundColor(); break;
        case 16: *reinterpret_cast<QColor*>(_v) = _t->linkBackgroundColor(); break;
        case 17: *reinterpret_cast<QColor*>(_v) = _t->visitedLinkBackgroundColor(); break;
        case 18: *reinterpret_cast<QColor*>(_v) = _t->negativeBackgroundColor(); break;
        case 19: *reinterpret_cast<QColor*>(_v) = _t->neutralBackgroundColor(); break;
        case 20: *reinterpret_cast<QColor*>(_v) = _t->positiveBackgroundColor(); break;
        case 21: *reinterpret_cast<QColor*>(_v) = _t->focusColor(); break;
        case 22: *reinterpret_cast<QColor*>(_v) = _t->hoverColor(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->useAlternateBackgroundColor(); break;
        case 24: *reinterpret_cast<QFont*>(_v) = _t->defaultFont(); break;
        case 25: *reinterpret_cast<QFont*>(_v) = _t->smallFont(); break;
        case 26: *reinterpret_cast<QFont*>(_v) = _t->fixedWidthFont(); break;
        case 27: *reinterpret_cast<QPalette*>(_v) = _t->palette(); break;
        case 28: *reinterpret_cast<qreal*>(_v) = _t->frameContrast(); break;
        case 29: *reinterpret_cast<qreal*>(_v) = _t->lightFrameContrast(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorSet(*reinterpret_cast<enum ColorSet*>(_v)); break;
        case 1: _t->setColorGroup(*reinterpret_cast<enum ColorGroup*>(_v)); break;
        case 2: _t->setInherit(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setCustomTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setCustomDisabledTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setCustomHighlightedTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setCustomActiveTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 7: _t->setCustomLinkColor(*reinterpret_cast<QColor*>(_v)); break;
        case 8: _t->setCustomVisitedLinkColor(*reinterpret_cast<QColor*>(_v)); break;
        case 9: _t->setCustomNegativeTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 10: _t->setCustomNeutralTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 11: _t->setCustomPositiveTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 12: _t->setCustomBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 13: _t->setCustomAlternateBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 14: _t->setCustomHighlightColor(*reinterpret_cast<QColor*>(_v)); break;
        case 15: _t->setCustomActiveBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 16: _t->setCustomLinkBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 17: _t->setCustomVisitedLinkBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 18: _t->setCustomNegativeBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 19: _t->setCustomNeutralBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 20: _t->setCustomPositiveBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 21: _t->setCustomFocusColor(*reinterpret_cast<QColor*>(_v)); break;
        case 22: _t->setCustomHoverColor(*reinterpret_cast<QColor*>(_v)); break;
        case 23: _t->setUseAlternateBackgroundColor(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 3: _t->setCustomTextColor(); break;
        case 4: _t->setCustomDisabledTextColor(); break;
        case 5: _t->setCustomHighlightedTextColor(); break;
        case 6: _t->setCustomActiveTextColor(); break;
        case 7: _t->setCustomLinkColor(); break;
        case 8: _t->setCustomVisitedLinkColor(); break;
        case 9: _t->setCustomNegativeTextColor(); break;
        case 10: _t->setCustomNeutralTextColor(); break;
        case 11: _t->setCustomPositiveTextColor(); break;
        case 12: _t->setCustomBackgroundColor(); break;
        case 13: _t->setCustomAlternateBackgroundColor(); break;
        case 14: _t->setCustomHighlightColor(); break;
        case 15: _t->setCustomActiveBackgroundColor(); break;
        case 16: _t->setCustomLinkBackgroundColor(); break;
        case 17: _t->setCustomVisitedLinkBackgroundColor(); break;
        case 18: _t->setCustomNegativeBackgroundColor(); break;
        case 19: _t->setCustomNeutralBackgroundColor(); break;
        case 20: _t->setCustomPositiveBackgroundColor(); break;
        case 21: _t->setCustomFocusColor(); break;
        case 22: _t->setCustomHoverColor(); break;
        default: break;
        }
    }
}

const QMetaObject *Kirigami::Platform::PlatformTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::Platform::PlatformTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform13PlatformThemeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::Platform::PlatformTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void Kirigami::Platform::PlatformTheme::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kirigami::Platform::PlatformTheme::defaultFontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kirigami::Platform::PlatformTheme::smallFontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kirigami::Platform::PlatformTheme::fixedWidthFontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Kirigami::Platform::PlatformTheme::colorSetChanged(Kirigami::Platform::PlatformTheme::ColorSet _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Kirigami::Platform::PlatformTheme::colorGroupChanged(Kirigami::Platform::PlatformTheme::ColorGroup _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Kirigami::Platform::PlatformTheme::paletteChanged(const QPalette & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Kirigami::Platform::PlatformTheme::inheritChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Kirigami::Platform::PlatformTheme::useAlternateBackgroundColorChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Kirigami::Platform::PlatformTheme::frameContrastChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
