/****************************************************************************
** Meta object code from reading C++ file 'padding.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.29.0/src/layouts/padding.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'padding.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7PaddingE_t {};
} // unnamed namespace

template <> constexpr inline auto Padding::qt_create_metaobjectdata<qt_meta_tag_ZN7PaddingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Padding",
        "QML.Element",
        "auto",
        "contentItemChanged",
        "",
        "paddingChanged",
        "horizontalPaddingChanged",
        "verticalPaddingChanged",
        "leftPaddingChanged",
        "topPaddingChanged",
        "rightPaddingChanged",
        "bottomPaddingChanged",
        "availableHeightChanged",
        "availableWidthChanged",
        "implicitContentWidthChanged",
        "implicitContentHeightChanged",
        "contentItem",
        "QQuickItem*",
        "padding",
        "horizontalPadding",
        "verticalPadding",
        "leftPadding",
        "topPadding",
        "rightPadding",
        "bottomPadding",
        "availableWidth",
        "availableHeight",
        "implicitContentWidth",
        "implicitContentHeight"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'contentItemChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paddingChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalPaddingChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verticalPaddingChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftPaddingChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topPaddingChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightPaddingChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomPaddingChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableHeightChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableWidthChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'implicitContentWidthChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'implicitContentHeightChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'contentItem'
        QtMocHelpers::PropertyData<QQuickItem*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'padding'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 1),
        // property 'horizontalPadding'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 2),
        // property 'verticalPadding'
        QtMocHelpers::PropertyData<qreal>(20, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 3),
        // property 'leftPadding'
        QtMocHelpers::PropertyData<qreal>(21, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 4),
        // property 'topPadding'
        QtMocHelpers::PropertyData<qreal>(22, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 5),
        // property 'rightPadding'
        QtMocHelpers::PropertyData<qreal>(23, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 6),
        // property 'bottomPadding'
        QtMocHelpers::PropertyData<qreal>(24, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 7),
        // property 'availableWidth'
        QtMocHelpers::PropertyData<qreal>(25, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'availableHeight'
        QtMocHelpers::PropertyData<qreal>(26, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'implicitContentWidth'
        QtMocHelpers::PropertyData<qreal>(27, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 10),
        // property 'implicitContentHeight'
        QtMocHelpers::PropertyData<qreal>(28, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Padding, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Padding::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PaddingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PaddingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PaddingE_t>.metaTypes,
    nullptr
} };

void Padding::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Padding *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->contentItemChanged(); break;
        case 1: _t->paddingChanged(); break;
        case 2: _t->horizontalPaddingChanged(); break;
        case 3: _t->verticalPaddingChanged(); break;
        case 4: _t->leftPaddingChanged(); break;
        case 5: _t->topPaddingChanged(); break;
        case 6: _t->rightPaddingChanged(); break;
        case 7: _t->bottomPaddingChanged(); break;
        case 8: _t->availableHeightChanged(); break;
        case 9: _t->availableWidthChanged(); break;
        case 10: _t->implicitContentWidthChanged(); break;
        case 11: _t->implicitContentHeightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::contentItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::paddingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::horizontalPaddingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::verticalPaddingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::leftPaddingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::topPaddingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::rightPaddingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::bottomPaddingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::availableHeightChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::availableWidthChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::implicitContentWidthChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Padding::*)()>(_a, &Padding::implicitContentHeightChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->contentItem(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->padding(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->horizontalPadding(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->verticalPadding(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->leftPadding(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->topPadding(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->rightPadding(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->bottomPadding(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->availableWidth(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->availableHeight(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->implicitContentWidth(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->implicitContentHeight(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setContentItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setHorizontalPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setVerticalPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setLeftPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setTopPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setRightPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setBottomPadding(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 1: _t->resetPadding(); break;
        case 2: _t->resetHorizontalPadding(); break;
        case 3: _t->resetVerticalPadding(); break;
        case 4: _t->resetLeftPadding(); break;
        case 5: _t->resetTopPadding(); break;
        case 6: _t->resetRightPadding(); break;
        case 7: _t->resetBottomPadding(); break;
        default: break;
        }
    }
}

const QMetaObject *Padding::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Padding::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PaddingE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Padding::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Padding::contentItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Padding::paddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Padding::horizontalPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Padding::verticalPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Padding::leftPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Padding::topPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Padding::rightPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Padding::bottomPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Padding::availableHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Padding::availableWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Padding::implicitContentWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Padding::implicitContentHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
