/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<columnview.h>)
#  include <columnview.h>
#endif
#if __has_include(<displayhint.h>)
#  include <displayhint.h>
#endif
#if __has_include(<formlayoutattached.h>)
#  include <formlayoutattached.h>
#endif
#if __has_include(<headerfooterlayout.h>)
#  include <headerfooterlayout.h>
#endif
#if __has_include(<padding.h>)
#  include <padding.h>
#endif
#if __has_include(<pagestackattached.h>)
#  include <pagestackattached.h>
#endif
#if __has_include(<sizegroup.h>)
#  include <sizegroup.h>
#endif
#if __has_include(<toolbarlayout.h>)
#  include <toolbarlayout.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigami_layouts()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ColumnView>("org.kde.kirigami.layouts", 2);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.kirigami.layouts", 2);
    qmlRegisterEnum<ColumnView::ColumnResizeMode>("ColumnView::ColumnResizeMode");
    QMetaType::fromType<ColumnViewAttached *>().id();
    qmlRegisterTypesAndRevisions<DisplayHint>("org.kde.kirigami.layouts", 2);
    qmlRegisterEnum<DisplayHint::Hint>("DisplayHint::Hint");
    qmlRegisterEnum<DisplayHint::DisplayHints>("DisplayHint::DisplayHints");
    qmlRegisterEnum<DisplayHint::Hint>("DisplayHint::Hint");
    qmlRegisterTypesAndRevisions<FormLayoutAttached>("org.kde.kirigami.layouts", 2);
    qmlRegisterTypesAndRevisions<HeaderFooterLayout>("org.kde.kirigami.layouts", 2);
    qmlRegisterTypesAndRevisions<Padding>("org.kde.kirigami.layouts", 2);
    qmlRegisterTypesAndRevisions<PageStackAttached>("org.kde.kirigami.layouts", 2);
    QMetaType::fromType<QQuickAttachedPropertyPropagator *>().id();
    qmlRegisterTypesAndRevisions<SizeGroup>("org.kde.kirigami.layouts", 2);
    qmlRegisterEnum<SizeGroup::Mode>("SizeGroup::Mode");
    qmlRegisterTypesAndRevisions<ToolBarLayout>("org.kde.kirigami.layouts", 2);
    qmlRegisterEnum<ToolBarLayout::HeightMode>("ToolBarLayout::HeightMode");
    QMetaType::fromType<ToolBarLayoutAttached *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigami.layouts", 2, 0);
}

static const QQmlModuleRegistration orgkdekirigamilayoutsRegistration("org.kde.kirigami.layouts", qml_register_types_org_kde_kirigami_layouts);
