/****************************************************************************
** Meta object code from reading C++ file 'basictheme_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.29.0/src/platform/basictheme_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'basictheme_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Kirigami8Platform20BasicThemeDefinitionE_t {};
} // unnamed namespace

template <> constexpr inline auto Kirigami::Platform::BasicThemeDefinition::qt_create_metaobjectdata<qt_meta_tag_ZN8Kirigami8Platform20BasicThemeDefinitionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kirigami::Platform::BasicThemeDefinition",
        "QML.Element",
        "auto",
        "changed",
        "",
        "sync",
        "QQuickItem*",
        "object",
        "textColor",
        "QColor",
        "disabledTextColor",
        "highlightColor",
        "highlightedTextColor",
        "backgroundColor",
        "alternateBackgroundColor",
        "focusColor",
        "hoverColor",
        "activeTextColor",
        "activeBackgroundColor",
        "linkColor",
        "linkBackgroundColor",
        "visitedLinkColor",
        "visitedLinkBackgroundColor",
        "negativeTextColor",
        "negativeBackgroundColor",
        "neutralTextColor",
        "neutralBackgroundColor",
        "positiveTextColor",
        "positiveBackgroundColor",
        "buttonTextColor",
        "buttonBackgroundColor",
        "buttonAlternateBackgroundColor",
        "buttonHoverColor",
        "buttonFocusColor",
        "viewTextColor",
        "viewBackgroundColor",
        "viewAlternateBackgroundColor",
        "viewHoverColor",
        "viewFocusColor",
        "selectionTextColor",
        "selectionBackgroundColor",
        "selectionAlternateBackgroundColor",
        "selectionHoverColor",
        "selectionFocusColor",
        "tooltipTextColor",
        "tooltipBackgroundColor",
        "tooltipAlternateBackgroundColor",
        "tooltipHoverColor",
        "tooltipFocusColor",
        "complementaryTextColor",
        "complementaryBackgroundColor",
        "complementaryAlternateBackgroundColor",
        "complementaryHoverColor",
        "complementaryFocusColor",
        "headerTextColor",
        "headerBackgroundColor",
        "headerAlternateBackgroundColor",
        "headerHoverColor",
        "headerFocusColor",
        "defaultFont",
        "QFont",
        "smallFont"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sync'
        QtMocHelpers::SignalData<void(QQuickItem *)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'disabledTextColor'
        QtMocHelpers::PropertyData<QColor>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'highlightColor'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'highlightedTextColor'
        QtMocHelpers::PropertyData<QColor>(12, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(13, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'alternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'focusColor'
        QtMocHelpers::PropertyData<QColor>(15, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'hoverColor'
        QtMocHelpers::PropertyData<QColor>(16, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'activeTextColor'
        QtMocHelpers::PropertyData<QColor>(17, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'activeBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'linkColor'
        QtMocHelpers::PropertyData<QColor>(19, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'linkBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(20, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'visitedLinkColor'
        QtMocHelpers::PropertyData<QColor>(21, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'visitedLinkBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'negativeTextColor'
        QtMocHelpers::PropertyData<QColor>(23, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'negativeBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(24, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'neutralTextColor'
        QtMocHelpers::PropertyData<QColor>(25, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'neutralBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'positiveTextColor'
        QtMocHelpers::PropertyData<QColor>(27, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'positiveBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(28, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'buttonTextColor'
        QtMocHelpers::PropertyData<QColor>(29, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'buttonBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(30, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'buttonAlternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(31, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'buttonHoverColor'
        QtMocHelpers::PropertyData<QColor>(32, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'buttonFocusColor'
        QtMocHelpers::PropertyData<QColor>(33, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'viewTextColor'
        QtMocHelpers::PropertyData<QColor>(34, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'viewBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(35, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'viewAlternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(36, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'viewHoverColor'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'viewFocusColor'
        QtMocHelpers::PropertyData<QColor>(38, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'selectionTextColor'
        QtMocHelpers::PropertyData<QColor>(39, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'selectionBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(40, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'selectionAlternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(41, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'selectionHoverColor'
        QtMocHelpers::PropertyData<QColor>(42, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'selectionFocusColor'
        QtMocHelpers::PropertyData<QColor>(43, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'tooltipTextColor'
        QtMocHelpers::PropertyData<QColor>(44, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'tooltipBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(45, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'tooltipAlternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(46, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'tooltipHoverColor'
        QtMocHelpers::PropertyData<QColor>(47, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'tooltipFocusColor'
        QtMocHelpers::PropertyData<QColor>(48, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'complementaryTextColor'
        QtMocHelpers::PropertyData<QColor>(49, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'complementaryBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(50, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'complementaryAlternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(51, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'complementaryHoverColor'
        QtMocHelpers::PropertyData<QColor>(52, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'complementaryFocusColor'
        QtMocHelpers::PropertyData<QColor>(53, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'headerTextColor'
        QtMocHelpers::PropertyData<QColor>(54, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'headerBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(55, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'headerAlternateBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(56, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'headerHoverColor'
        QtMocHelpers::PropertyData<QColor>(57, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'headerFocusColor'
        QtMocHelpers::PropertyData<QColor>(58, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'defaultFont'
        QtMocHelpers::PropertyData<QFont>(59, 0x80000000 | 60, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'smallFont'
        QtMocHelpers::PropertyData<QFont>(61, 0x80000000 | 60, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<BasicThemeDefinition, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Kirigami::Platform::BasicThemeDefinition::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform20BasicThemeDefinitionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform20BasicThemeDefinitionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Kirigami8Platform20BasicThemeDefinitionE_t>.metaTypes,
    nullptr
} };

void Kirigami::Platform::BasicThemeDefinition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BasicThemeDefinition *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->sync((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BasicThemeDefinition::*)()>(_a, &BasicThemeDefinition::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BasicThemeDefinition::*)(QQuickItem * )>(_a, &BasicThemeDefinition::sync, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->textColor; break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->disabledTextColor; break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->highlightColor; break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->highlightedTextColor; break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor; break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->alternateBackgroundColor; break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->focusColor; break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->hoverColor; break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->activeTextColor; break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->activeBackgroundColor; break;
        case 10: *reinterpret_cast<QColor*>(_v) = _t->linkColor; break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->linkBackgroundColor; break;
        case 12: *reinterpret_cast<QColor*>(_v) = _t->visitedLinkColor; break;
        case 13: *reinterpret_cast<QColor*>(_v) = _t->visitedLinkBackgroundColor; break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->negativeTextColor; break;
        case 15: *reinterpret_cast<QColor*>(_v) = _t->negativeBackgroundColor; break;
        case 16: *reinterpret_cast<QColor*>(_v) = _t->neutralTextColor; break;
        case 17: *reinterpret_cast<QColor*>(_v) = _t->neutralBackgroundColor; break;
        case 18: *reinterpret_cast<QColor*>(_v) = _t->positiveTextColor; break;
        case 19: *reinterpret_cast<QColor*>(_v) = _t->positiveBackgroundColor; break;
        case 20: *reinterpret_cast<QColor*>(_v) = _t->buttonTextColor; break;
        case 21: *reinterpret_cast<QColor*>(_v) = _t->buttonBackgroundColor; break;
        case 22: *reinterpret_cast<QColor*>(_v) = _t->buttonAlternateBackgroundColor; break;
        case 23: *reinterpret_cast<QColor*>(_v) = _t->buttonHoverColor; break;
        case 24: *reinterpret_cast<QColor*>(_v) = _t->buttonFocusColor; break;
        case 25: *reinterpret_cast<QColor*>(_v) = _t->viewTextColor; break;
        case 26: *reinterpret_cast<QColor*>(_v) = _t->viewBackgroundColor; break;
        case 27: *reinterpret_cast<QColor*>(_v) = _t->viewAlternateBackgroundColor; break;
        case 28: *reinterpret_cast<QColor*>(_v) = _t->viewHoverColor; break;
        case 29: *reinterpret_cast<QColor*>(_v) = _t->viewFocusColor; break;
        case 30: *reinterpret_cast<QColor*>(_v) = _t->selectionTextColor; break;
        case 31: *reinterpret_cast<QColor*>(_v) = _t->selectionBackgroundColor; break;
        case 32: *reinterpret_cast<QColor*>(_v) = _t->selectionAlternateBackgroundColor; break;
        case 33: *reinterpret_cast<QColor*>(_v) = _t->selectionHoverColor; break;
        case 34: *reinterpret_cast<QColor*>(_v) = _t->selectionFocusColor; break;
        case 35: *reinterpret_cast<QColor*>(_v) = _t->tooltipTextColor; break;
        case 36: *reinterpret_cast<QColor*>(_v) = _t->tooltipBackgroundColor; break;
        case 37: *reinterpret_cast<QColor*>(_v) = _t->tooltipAlternateBackgroundColor; break;
        case 38: *reinterpret_cast<QColor*>(_v) = _t->tooltipHoverColor; break;
        case 39: *reinterpret_cast<QColor*>(_v) = _t->tooltipFocusColor; break;
        case 40: *reinterpret_cast<QColor*>(_v) = _t->complementaryTextColor; break;
        case 41: *reinterpret_cast<QColor*>(_v) = _t->complementaryBackgroundColor; break;
        case 42: *reinterpret_cast<QColor*>(_v) = _t->complementaryAlternateBackgroundColor; break;
        case 43: *reinterpret_cast<QColor*>(_v) = _t->complementaryHoverColor; break;
        case 44: *reinterpret_cast<QColor*>(_v) = _t->complementaryFocusColor; break;
        case 45: *reinterpret_cast<QColor*>(_v) = _t->headerTextColor; break;
        case 46: *reinterpret_cast<QColor*>(_v) = _t->headerBackgroundColor; break;
        case 47: *reinterpret_cast<QColor*>(_v) = _t->headerAlternateBackgroundColor; break;
        case 48: *reinterpret_cast<QColor*>(_v) = _t->headerHoverColor; break;
        case 49: *reinterpret_cast<QColor*>(_v) = _t->headerFocusColor; break;
        case 50: *reinterpret_cast<QFont*>(_v) = _t->defaultFont; break;
        case 51: *reinterpret_cast<QFont*>(_v) = _t->smallFont; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->textColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->disabledTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->highlightColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->highlightedTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->backgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->alternateBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->focusColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->hoverColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->activeTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->activeBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 10:
            if (QtMocHelpers::setProperty(_t->linkColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 11:
            if (QtMocHelpers::setProperty(_t->linkBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 12:
            if (QtMocHelpers::setProperty(_t->visitedLinkColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->visitedLinkBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 14:
            if (QtMocHelpers::setProperty(_t->negativeTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 15:
            if (QtMocHelpers::setProperty(_t->negativeBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 16:
            if (QtMocHelpers::setProperty(_t->neutralTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 17:
            if (QtMocHelpers::setProperty(_t->neutralBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 18:
            if (QtMocHelpers::setProperty(_t->positiveTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 19:
            if (QtMocHelpers::setProperty(_t->positiveBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 20:
            if (QtMocHelpers::setProperty(_t->buttonTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 21:
            if (QtMocHelpers::setProperty(_t->buttonBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 22:
            if (QtMocHelpers::setProperty(_t->buttonAlternateBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 23:
            if (QtMocHelpers::setProperty(_t->buttonHoverColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 24:
            if (QtMocHelpers::setProperty(_t->buttonFocusColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 25:
            if (QtMocHelpers::setProperty(_t->viewTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 26:
            if (QtMocHelpers::setProperty(_t->viewBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 27:
            if (QtMocHelpers::setProperty(_t->viewAlternateBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 28:
            if (QtMocHelpers::setProperty(_t->viewHoverColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 29:
            if (QtMocHelpers::setProperty(_t->viewFocusColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 30:
            if (QtMocHelpers::setProperty(_t->selectionTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 31:
            if (QtMocHelpers::setProperty(_t->selectionBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 32:
            if (QtMocHelpers::setProperty(_t->selectionAlternateBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 33:
            if (QtMocHelpers::setProperty(_t->selectionHoverColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 34:
            if (QtMocHelpers::setProperty(_t->selectionFocusColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 35:
            if (QtMocHelpers::setProperty(_t->tooltipTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 36:
            if (QtMocHelpers::setProperty(_t->tooltipBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 37:
            if (QtMocHelpers::setProperty(_t->tooltipAlternateBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 38:
            if (QtMocHelpers::setProperty(_t->tooltipHoverColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 39:
            if (QtMocHelpers::setProperty(_t->tooltipFocusColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 40:
            if (QtMocHelpers::setProperty(_t->complementaryTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 41:
            if (QtMocHelpers::setProperty(_t->complementaryBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 42:
            if (QtMocHelpers::setProperty(_t->complementaryAlternateBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 43:
            if (QtMocHelpers::setProperty(_t->complementaryHoverColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 44:
            if (QtMocHelpers::setProperty(_t->complementaryFocusColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 45:
            if (QtMocHelpers::setProperty(_t->headerTextColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 46:
            if (QtMocHelpers::setProperty(_t->headerBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 47:
            if (QtMocHelpers::setProperty(_t->headerAlternateBackgroundColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 48:
            if (QtMocHelpers::setProperty(_t->headerHoverColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 49:
            if (QtMocHelpers::setProperty(_t->headerFocusColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 50:
            if (QtMocHelpers::setProperty(_t->defaultFont, *reinterpret_cast<QFont*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 51:
            if (QtMocHelpers::setProperty(_t->smallFont, *reinterpret_cast<QFont*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *Kirigami::Platform::BasicThemeDefinition::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::Platform::BasicThemeDefinition::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform20BasicThemeDefinitionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::Platform::BasicThemeDefinition::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    return _id;
}

// SIGNAL 0
void Kirigami::Platform::BasicThemeDefinition::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kirigami::Platform::BasicThemeDefinition::sync(QQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN8Kirigami8Platform18BasicThemeInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto Kirigami::Platform::BasicThemeInstance::qt_create_metaobjectdata<qt_meta_tag_ZN8Kirigami8Platform18BasicThemeInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kirigami::Platform::BasicThemeInstance"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BasicThemeInstance, qt_meta_tag_ZN8Kirigami8Platform18BasicThemeInstanceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kirigami::Platform::BasicThemeInstance::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform18BasicThemeInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform18BasicThemeInstanceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Kirigami8Platform18BasicThemeInstanceE_t>.metaTypes,
    nullptr
} };

void Kirigami::Platform::BasicThemeInstance::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BasicThemeInstance *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Kirigami::Platform::BasicThemeInstance::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::Platform::BasicThemeInstance::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform18BasicThemeInstanceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::Platform::BasicThemeInstance::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8Kirigami8Platform10BasicThemeE_t {};
} // unnamed namespace

template <> constexpr inline auto Kirigami::Platform::BasicTheme::qt_create_metaobjectdata<qt_meta_tag_ZN8Kirigami8Platform10BasicThemeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kirigami::Platform::BasicTheme"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BasicTheme, qt_meta_tag_ZN8Kirigami8Platform10BasicThemeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kirigami::Platform::BasicTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<PlatformTheme::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform10BasicThemeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform10BasicThemeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Kirigami8Platform10BasicThemeE_t>.metaTypes,
    nullptr
} };

void Kirigami::Platform::BasicTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BasicTheme *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Kirigami::Platform::BasicTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::Platform::BasicTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Kirigami8Platform10BasicThemeE_t>.strings))
        return static_cast<void*>(this);
    return PlatformTheme::qt_metacast(_clname);
}

int Kirigami::Platform::BasicTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlatformTheme::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
