/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<enums.h>)
#  include <enums.h>
#endif
#if __has_include(<pagepool.h>)
#  include <pagepool.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigami_controls()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &ApplicationHeaderStyle::staticMetaObject;},
            "ApplicationHeaderStyle");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&ApplicationHeaderStyle::staticMetaObject, "org.kde.kirigami.controls", 2, nullptr, &ApplicationHeaderStyle::staticMetaObject, nullptr);
    qmlRegisterEnum<ApplicationHeaderStyle::Status>("ApplicationHeaderStyle::Status");
    qmlRegisterEnum<ApplicationHeaderStyle::NavigationButton>("ApplicationHeaderStyle::NavigationButton");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &MessageType::staticMetaObject;},
            "MessageType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&MessageType::staticMetaObject, "org.kde.kirigami.controls", 2, nullptr, &MessageType::staticMetaObject, nullptr);
    qmlRegisterEnum<MessageType::Type>("MessageType::Type");
    qmlRegisterTypesAndRevisions<PagePool>("org.kde.kirigami.controls", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigami.controls", 2, 0);
}

static const QQmlModuleRegistration orgkdekirigamicontrolsRegistration("org.kde.kirigami.controls", qml_register_types_org_kde_kirigami_controls);
